pub struct Args {
pub owner: Option<String>,
pub repo: Option<String>,
pub log_level: LogLevel,
pub print_log_dir: bool,
pub set_token: Option<String>,
pub generate_man: bool,
pub env: bool,
}Fields
owner: Option<String>GitHub repository owner or organization (for example: rust-lang).
This is required unless --print-log-dir or --set-token is provided.
repo: Option<String>GitHub repository name under owner (for example: rust).
This is required unless --print-log-dir or --set-token is provided.
log_level: LogLevelGlobal logging verbosity used by the application logger.
Defaults to info.
print_log_dir: boolPrints the directory where log files are written and exits.
set_token: Option<String>Stores/updates the GitHub token in the configured credential store.
When provided, this command updates the saved token value.
generate_man: boolGenerate man pages using clap-mangen and exit.
env: boolWhen provided, this command will read the GitHub token from the environment variable