pub struct GithubClient { /* private fields */ }Implementations
Methods from Deref<Target = Octocrab>
Sourcepub async fn authenticate_as_device<I, S>(
&self,
client_id: &SecretBox<str>,
scope: I,
) -> Result<DeviceCodes, Error>
pub async fn authenticate_as_device<I, S>( &self, client_id: &SecretBox<str>, scope: I, ) -> Result<DeviceCodes, Error>
Authenticate with Github’s device flow. This starts the process to obtain a new OAuth.
See https://docs.github.com/en/developers/apps/building-oauth-apps/authorizing-oauth-apps#device-flow for details.
Note: To authenticate against public Github, the Octocrab that calls this method
must be constructed with base_uri: "https://github.com" and extra header
“ACCEPT: application/json”. For example:
let crab = octocrab::Octocrab::builder()
.base_uri("https://github.com")?
.add_header(ACCEPT, "application/json".to_string())
.build()?;Sourcepub fn installation(&self, id: InstallationId) -> Result<Octocrab, Error>
pub fn installation(&self, id: InstallationId) -> Result<Octocrab, Error>
Returns a new Octocrab based on the current builder but
authorizing via a specific installation ID.
Typically you will first construct an Octocrab using
OctocrabBuilder::app to authenticate as your Github App,
then obtain an installation ID, and then pass that here to
obtain a new Octocrab with which you can make API calls
with the permissions of that installation.
Sourcepub async fn installation_and_token(
&self,
id: InstallationId,
) -> Result<(Octocrab, SecretBox<str>), Error>
pub async fn installation_and_token( &self, id: InstallationId, ) -> Result<(Octocrab, SecretBox<str>), Error>
Similar to installation, but also eagerly caches the installation
token and returns the token. The returned token can be used to make
https git requests to e.g. clone repositories that the installation
has access to.
Sourcepub async fn installation_token(&self) -> Result<SecretBox<str>, Error>
pub async fn installation_token(&self) -> Result<SecretBox<str>, Error>
Acquire a GitHub App installation access token that does not expire for at least 30 seconds. A cached token will be used if its expiration is far enough in the future. Otherwise, a new token will be acquired and cached.
Sourcepub async fn installation_token_with_buffer(
&self,
buffer: TimeDelta,
) -> Result<SecretBox<str>, Error>
pub async fn installation_token_with_buffer( &self, buffer: TimeDelta, ) -> Result<SecretBox<str>, Error>
Acquire a GitHub App installation access token that does not expire for
at least the duration specified by [buffer]. A cached token will be
used if its expiration is far enough in the future. Otherwise, a new
token will be acquired and cached.
Sourcepub fn user_access_token<S>(&self, token: S) -> Result<Octocrab, Error>
pub fn user_access_token<S>(&self, token: S) -> Result<Octocrab, Error>
Returns a new Octocrab based on the current builder but
authorizing via an access token.
Sourcepub fn actions(&self) -> ActionsHandler<'_>
pub fn actions(&self) -> ActionsHandler<'_>
Creates a new actions::ActionsHandler for accessing information from
GitHub Actions.
Sourcepub fn current(&self) -> CurrentAuthHandler<'_>
pub fn current(&self) -> CurrentAuthHandler<'_>
Creates a current::CurrentAuthHandler that allows you to access
information about the current authenticated user.
Sourcepub fn activity(&self) -> ActivityHandler<'_>
pub fn activity(&self) -> ActivityHandler<'_>
Creates a activity::ActivityHandler for the current authenticated user.
Sourcepub fn apps(&self) -> AppsRequestHandler<'_>
pub fn apps(&self) -> AppsRequestHandler<'_>
Creates a new apps::AppsRequestHandler for the currently authenticated app.
Sourcepub fn gitignore(&self) -> GitignoreHandler<'_>
pub fn gitignore(&self) -> GitignoreHandler<'_>
Creates a gitignore::GitignoreHandler for accessing information
about gitignore.
Sourcepub fn issues(
&self,
owner: impl Into<String>,
repo: impl Into<String>,
) -> IssueHandler<'_>
pub fn issues( &self, owner: impl Into<String>, repo: impl Into<String>, ) -> IssueHandler<'_>
Creates a issues::IssueHandler for the repo specified at owner/repo,
that allows you to access GitHub’s issues API.
Sourcepub fn issues_by_id(&self, id: impl Into<RepositoryId>) -> IssueHandler<'_>
pub fn issues_by_id(&self, id: impl Into<RepositoryId>) -> IssueHandler<'_>
Creates a issues::IssueHandler for the repo specified at repository ID,
that allows you to access GitHub’s issues API.
Sourcepub fn code_scannings(
&self,
owner: impl Into<String>,
repo: impl Into<String>,
) -> CodeScanningHandler<'_>
pub fn code_scannings( &self, owner: impl Into<String>, repo: impl Into<String>, ) -> CodeScanningHandler<'_>
Creates a code_scannings::CodeScanningHandler for the repo specified at owner/repo,
that allows you to access GitHub’s Code scanning API.
Sourcepub fn code_scannings_organisation(
&self,
owner: impl Into<String>,
) -> CodeScanningHandler<'_>
pub fn code_scannings_organisation( &self, owner: impl Into<String>, ) -> CodeScanningHandler<'_>
Creates a code_scannings::CodeScanningHandler for the org specified at owner,
that allows you to access GitHub’s Code scanning API.
Sourcepub fn commits(
&self,
owner: impl Into<String>,
repo: impl Into<String>,
) -> CommitHandler<'_>
pub fn commits( &self, owner: impl Into<String>, repo: impl Into<String>, ) -> CommitHandler<'_>
Creates a commits::CommitHandler for the repo specified at owner/repo,
Sourcepub fn licenses(&self) -> LicenseHandler<'_>
pub fn licenses(&self) -> LicenseHandler<'_>
Creates a licenses::LicenseHandler.
Sourcepub fn markdown(&self) -> MarkdownHandler<'_>
pub fn markdown(&self) -> MarkdownHandler<'_>
Creates a markdown::MarkdownHandler.
Sourcepub fn orgs(&self, owner: impl Into<String>) -> OrgHandler<'_>
pub fn orgs(&self, owner: impl Into<String>) -> OrgHandler<'_>
Creates an orgs::OrgHandler for the specified organization,
that allows you to access GitHub’s organization API.
Sourcepub fn pulls(
&self,
owner: impl Into<String>,
repo: impl Into<String>,
) -> PullRequestHandler<'_>
pub fn pulls( &self, owner: impl Into<String>, repo: impl Into<String>, ) -> PullRequestHandler<'_>
Creates a pulls::PullRequestHandler for the repo specified at
owner/repo, that allows you to access GitHub’s pull request API.
Sourcepub fn repos(
&self,
owner: impl Into<String>,
repo: impl Into<String>,
) -> RepoHandler<'_>
pub fn repos( &self, owner: impl Into<String>, repo: impl Into<String>, ) -> RepoHandler<'_>
Creates a repos::RepoHandler for the repo specified at owner/repo,
that allows you to access GitHub’s repository API.
Sourcepub fn repos_by_id(&self, id: impl Into<RepositoryId>) -> RepoHandler<'_>
pub fn repos_by_id(&self, id: impl Into<RepositoryId>) -> RepoHandler<'_>
Creates a repos::RepoHandler for the repo specified at repository ID,
that allows you to access GitHub’s repository API.
Sourcepub fn projects(&self) -> ProjectHandler<'_>
pub fn projects(&self) -> ProjectHandler<'_>
Creates a projects::ProjectHandler that allows you to access GitHub’s
projects API (classic).
Sourcepub fn search(&self) -> SearchHandler<'_>
pub fn search(&self) -> SearchHandler<'_>
Creates a search::SearchHandler that allows you to construct general queries
to GitHub’s API.
Sourcepub fn teams(&self, owner: impl Into<String>) -> TeamHandler<'_>
pub fn teams(&self, owner: impl Into<String>) -> TeamHandler<'_>
Creates a teams::TeamHandler for the specified organization that allows
you to access GitHub’s teams API.
Sourcepub fn users(&self, user: impl Into<String>) -> UserHandler<'_>
pub fn users(&self, user: impl Into<String>) -> UserHandler<'_>
Creates a users::UserHandler for the specified user using the user name
Sourcepub fn users_by_id(&self, user: impl Into<UserId>) -> UserHandler<'_>
pub fn users_by_id(&self, user: impl Into<UserId>) -> UserHandler<'_>
Creates a users::UserHandler for the specified user using the user ID
Sourcepub fn workflows(
&self,
owner: impl Into<String>,
repo: impl Into<String>,
) -> WorkflowsHandler<'_>
pub fn workflows( &self, owner: impl Into<String>, repo: impl Into<String>, ) -> WorkflowsHandler<'_>
Creates a workflows::WorkflowsHandler for the specified repository that allows
you to access GitHub’s workflows API.
Sourcepub fn events(&self) -> EventsBuilder<'_>
pub fn events(&self) -> EventsBuilder<'_>
Creates an events::EventsBuilder that allows you to access
GitHub’s events API.
Sourcepub fn gists(&self) -> GistsHandler<'_>
pub fn gists(&self) -> GistsHandler<'_>
Creates a gists::GistsHandler that allows you to access
GitHub’s Gists API.
Sourcepub fn checks(
&self,
owner: impl Into<String>,
repo: impl Into<String>,
) -> ChecksHandler<'_>
pub fn checks( &self, owner: impl Into<String>, repo: impl Into<String>, ) -> ChecksHandler<'_>
Creates a checks::ChecksHandler that allows to access the Checks API.
Sourcepub fn ratelimit(&self) -> RateLimitHandler<'_>
pub fn ratelimit(&self) -> RateLimitHandler<'_>
Creates a ratelimit::RateLimitHandler that returns the API rate limit.
Sourcepub fn hooks(&self, owner: impl Into<String>) -> HooksHandler<'_>
pub fn hooks(&self, owner: impl Into<String>) -> HooksHandler<'_>
Creates a hooks::HooksHandler that returns the API hooks
Sourcepub fn assignments(&self) -> AssignmentsHandler<'_>
pub fn assignments(&self) -> AssignmentsHandler<'_>
Creates a classroom::AssignmentsHandler providing the GitHub Classroom Assignments API
Sourcepub fn classrooms(&self) -> ClassroomHandler<'_>
pub fn classrooms(&self) -> ClassroomHandler<'_>
Creates a classroom::ClassroomHandler providing the GitHub Classroom Classrooms API
Sourcepub fn codes_of_conduct(&self) -> CodesOfConductHandler<'_>
pub fn codes_of_conduct(&self) -> CodesOfConductHandler<'_>
Creates a [codes_of_conduct::CodesOfConductHandler] providing the GitHub Codes of Codes of Conduct API
Sourcepub async fn graphql<R>(
&self,
payload: &(impl Serialize + ?Sized),
) -> Result<R, Error>where
R: FromResponse,
pub async fn graphql<R>(
&self,
payload: &(impl Serialize + ?Sized),
) -> Result<R, Error>where
R: FromResponse,
Sends a graphql query to GitHub, and deserialises the response from JSON.
let response: serde_json::Value = octocrab::instance()
.graphql(&serde_json::json!({ "query": "{ viewer { login }}" }))
.await?;Sourcepub async fn post<P, R>(
&self,
route: impl AsRef<str>,
body: Option<&P>,
) -> Result<R, Error>
pub async fn post<P, R>( &self, route: impl AsRef<str>, body: Option<&P>, ) -> Result<R, Error>
Send a POST request to route with an optional body, returning the body
of the response.
Sourcepub async fn _post<P>(
&self,
uri: impl TryInto<Uri>,
body: Option<&P>,
) -> Result<Response<BoxBody<Bytes, Error>>, Error>
pub async fn _post<P>( &self, uri: impl TryInto<Uri>, body: Option<&P>, ) -> Result<Response<BoxBody<Bytes, Error>>, Error>
Send a POST request with no additional pre/post-processing.
Sourcepub async fn get<R, A, P>(
&self,
route: A,
parameters: Option<&P>,
) -> Result<R, Error>
pub async fn get<R, A, P>( &self, route: A, parameters: Option<&P>, ) -> Result<R, Error>
Send a GET request to route with optional query parameters, returning
the body of the response.
Sourcepub async fn _get(
&self,
uri: impl TryInto<Uri>,
) -> Result<Response<BoxBody<Bytes, Error>>, Error>
pub async fn _get( &self, uri: impl TryInto<Uri>, ) -> Result<Response<BoxBody<Bytes, Error>>, Error>
Send a GET request with no additional post-processing.
pub async fn body_to_string( &self, res: Response<BoxBody<Bytes, Error>>, ) -> Result<String, Error>
Sourcepub async fn get_with_headers<R, A, P>(
&self,
route: A,
parameters: Option<&P>,
headers: Option<HeaderMap>,
) -> Result<R, Error>
pub async fn get_with_headers<R, A, P>( &self, route: A, parameters: Option<&P>, headers: Option<HeaderMap>, ) -> Result<R, Error>
Send a GET request to route with optional query parameters and headers, returning
the body of the response.
Sourcepub async fn _get_with_headers(
&self,
uri: impl TryInto<Uri>,
headers: Option<HeaderMap>,
) -> Result<Response<BoxBody<Bytes, Error>>, Error>
pub async fn _get_with_headers( &self, uri: impl TryInto<Uri>, headers: Option<HeaderMap>, ) -> Result<Response<BoxBody<Bytes, Error>>, Error>
Send a GET request including option to set headers, with no additional post-processing.
Sourcepub async fn patch<R, A, B>(
&self,
route: A,
body: Option<&B>,
) -> Result<R, Error>
pub async fn patch<R, A, B>( &self, route: A, body: Option<&B>, ) -> Result<R, Error>
Send a PATCH request to route with optional query parameters,
returning the body of the response.
Sourcepub async fn _patch<B>(
&self,
uri: impl TryInto<Uri>,
body: Option<&B>,
) -> Result<Response<BoxBody<Bytes, Error>>, Error>
pub async fn _patch<B>( &self, uri: impl TryInto<Uri>, body: Option<&B>, ) -> Result<Response<BoxBody<Bytes, Error>>, Error>
Send a PATCH request with no additional post-processing.
Sourcepub async fn put<R, A, B>(&self, route: A, body: Option<&B>) -> Result<R, Error>
pub async fn put<R, A, B>(&self, route: A, body: Option<&B>) -> Result<R, Error>
Send a PUT request to route with optional query parameters,
returning the body of the response.
Sourcepub async fn _put<B>(
&self,
uri: impl TryInto<Uri>,
body: Option<&B>,
) -> Result<Response<BoxBody<Bytes, Error>>, Error>
pub async fn _put<B>( &self, uri: impl TryInto<Uri>, body: Option<&B>, ) -> Result<Response<BoxBody<Bytes, Error>>, Error>
Send a PUT request with no additional post-processing.
pub fn build_request<B>( &self, builder: Builder, body: Option<&B>, ) -> Result<Request<OctoBody>, Error>
Sourcepub async fn delete<R, A, B>(
&self,
route: A,
body: Option<&B>,
) -> Result<R, Error>
pub async fn delete<R, A, B>( &self, route: A, body: Option<&B>, ) -> Result<R, Error>
Send a DELETE request to route with optional query body,
returning the body of the response.
Sourcepub async fn _delete<B>(
&self,
uri: impl TryInto<Uri>,
body: Option<&B>,
) -> Result<Response<BoxBody<Bytes, Error>>, Error>
pub async fn _delete<B>( &self, uri: impl TryInto<Uri>, body: Option<&B>, ) -> Result<Response<BoxBody<Bytes, Error>>, Error>
Send a DELETE request with no additional post-processing.
Sourcepub async fn send(
&self,
request: Request<OctoBody>,
) -> Result<Response<BoxBody<Bytes, Error>>, Error>
pub async fn send( &self, request: Request<OctoBody>, ) -> Result<Response<BoxBody<Bytes, Error>>, Error>
Send the given request to the underlying service
Sourcepub async fn execute(
&self,
request: Request<impl Into<OctoBody>>,
) -> Result<Response<BoxBody<Bytes, Error>>, Error>
pub async fn execute( &self, request: Request<impl Into<OctoBody>>, ) -> Result<Response<BoxBody<Bytes, Error>>, Error>
Execute the given request using octocrab’s Client.
pub async fn follow_location_to_data( &self, response: Response<BoxBody<Bytes, Error>>, ) -> Result<Response<BoxBody<Bytes, Error>>, Error>
Sourcepub async fn download(
&self,
uri: impl TryInto<Uri>,
content_type: impl TryInto<HeaderValue>,
) -> Result<Vec<u8>, Error>
pub async fn download( &self, uri: impl TryInto<Uri>, content_type: impl TryInto<HeaderValue>, ) -> Result<Vec<u8>, Error>
Download a file from the given URL with the given content type
This is a convenience method that sets the Accept header to the given
content type and downloads the file into a Vec<u8>.
Sourcepub async fn download_zip(
&self,
uri: impl TryInto<Uri>,
) -> Result<Vec<u8>, Error>
pub async fn download_zip( &self, uri: impl TryInto<Uri>, ) -> Result<Vec<u8>, Error>
Download a zip file from the given URL into a Vec<u8>.